@@ -2,17 +2,18 @@
 
     Copyright (C) 2000,2001 Stefan Westerfeld
                             stefan@space.twc.de
+                       2002 Matthias Kretz <kretz@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
     License as published by the Free Software Foundation; either
     version 2 of the License, or (at your option) any later version.
-  
+
     This library is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
     Library General Public License for more details.
-   
+
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
     the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
@@ -21,16 +22,30 @@
     */
 
 #include "kvbox_impl.h"
+#include <qvbox.h>
 
 using namespace Arts;
-using namespace std;
 
-KVBox_impl::KVBox_impl(QVBox *qvbox /* = 0 */)
-	: KWidget_impl(qvbox?qvbox:new QVBox((QWidget *)0))
+KVBox_impl::KVBox_impl( QVBox * widget )
+	: KFrame_impl( widget ? widget : new QVBox )
+	, _spacing( 5 )
 {
-	this->qvbox = (QVBox *)qwidget;
-	this->qvbox->setMargin(5);
-	this->qvbox->setSpacing(5);
+	_qvbox = static_cast<QVBox*>( _qwidget );
+	_qvbox->setSpacing( _spacing );
+	_qvbox->setMargin( 5 );
+}
+
+long KVBox_impl::spacing()
+{
+	return _spacing;
+}
+
+void KVBox_impl::spacing( long s )
+{
+	_spacing = s;
+	_qvbox->setSpacing( s );
 }
 
 REGISTER_IMPLEMENTATION(KVBox_impl);
+
+// vim: sw=4 ts=4
