@@ -10,7 +10,7 @@ class KMidIface : virtual public DCOPObject
 k_dcop:
 // File
 
-   virtual int openURL( QString s )=0;
+   virtual int openURL( const QString s )=0;
 
  // Song
    virtual void play()=0;
