@@ -27,7 +27,7 @@
 namespace KCDDB
 {
   HTTPLookup::HTTPLookup()
-    : QObject(), Lookup(),
+    : Lookup(),
       block_( true ), state_( Idle ), result_( Success )
   {
   }
@@ -91,17 +91,9 @@ namespace KCDDB
   }
 
     void
-  HTTPLookup::slotResult( KIO::Job *job )
+  HTTPLookup::jobFinished()
   {
-    if ( 0 != job->error() )
-    {
-      result_ = ServerError;
-      if ( !block_ )
-        emit queryReady();
-      return;
-    }
-
-    QStringList lineList = QStringList::split( "\n", QString::fromUtf8(data_) );
+    QStringList lineList = QStringList::split( "\n", QString::fromUtf8(data_, data_.size()) );
     QStringList::ConstIterator it = lineList.begin();
 
     switch ( state_ )
@@ -166,16 +158,18 @@ namespace KCDDB
         {
           CDInfo info;
 
-          if ( info.load( QString::fromUtf8(data_) ) )
-	  {
-	    info.category = category_;
+          if ( info.load( QString::fromUtf8(data_,data_.size()) ) )
+          {
+            info.category = category_;
             cdInfoList_.append( info );
-	  }
+          }
 
           if ( !block_ )
             emit readReady();
         }
 
+        return;
+
         break; 
 
       default:
