@@ -71,7 +71,7 @@ void rgb2yuv16bit_mmx_fast(unsigned char* ,unsigned char* ,unsigned char* ,
 
 void rgb2yuv16(unsigned char* rgbSource, unsigned char* dest)
 {
-	int rgb = *((unsigned short*) rgbSource)++;
+	int rgb = *((unsigned short*) rgbSource++ );
 	int r = RED(rgb);
 	int g = GREEN(rgb);
 	int b = BLUE(rgb);
@@ -92,7 +92,7 @@ void rgb2yuv16bit(unsigned char* rgbSource,
 
 	for (row=0 ; row<height2 ; row++) {
 		for (col=0 ; col<width2 ; col++) {
-			rgb = *((unsigned short*) rgbSource)++;
+			rgb = *((unsigned short*) rgbSource++ );
   			r = RED(rgb);
   			g = GREEN(rgb);
   			b = BLUE(rgb);
@@ -101,7 +101,7 @@ void rgb2yuv16bit(unsigned char* rgbSource,
 			*cr++  = U_RGB(r, g, b);
 			*cb++  = V_RGB(r, g, b);
 			
-			rgb = *((unsigned short*) rgbSource)++;
+			rgb = *((unsigned short*) rgbSource++ );
   			r = RED(rgb);
   			g = GREEN(rgb);
   			b = BLUE(rgb);
@@ -109,7 +109,7 @@ void rgb2yuv16bit(unsigned char* rgbSource,
 			*lum++ = Y_RGB(r, g, b);
 		}
 		for (col=0 ; col<width ; col++) {
-			rgb = *((unsigned short*) rgbSource)++;
+			rgb = *((unsigned short*) rgbSource++ );
   			r = RED(rgb);
   			g = GREEN(rgb);
   			b = BLUE(rgb);
@@ -485,7 +485,7 @@ void rgb2yuv16bit_mmx422_row(unsigned char* rgb,
 
 		:
 		: "r" (rgb), "r" (lum), "r" (cr), "r" (cb),
-		"m" (pixel), "m" (buf)
+		"m" (pixel), "m" (buf[0])
 
 		);
 }
@@ -854,7 +854,7 @@ void rgb2y16bit_mmx_row(unsigned char* rgbSource,
 		"emms\n"
 
 		:
-		: "r" (rgbSource), "r" (lum), "m" (pixel), "m" (buf)
+		: "r" (rgbSource), "r" (lum), "m" (pixel), "m" (buf[0])
 		
 	);
 }
